==> checkstyle_8.29.orig.tar.xz: checkstyle-checkstyle-8.29/src/it/java/org/checkstyle/suppressionxpathfilter/XpathRegressionAvoidNoArgumentSuperConstructorCallTest.java <==
////////////////////////////////////////////////////////////////////////////////
// checkstyle: Checks Java source code for adherence to a set of rules.
// Copyright (C) 2001-2020 the original author or authors.
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

package org.checkstyle.suppressionxpathfilter;

import java.io.File;
import java.util.Collections;
import java.util.List;

import org.junit.jupiter.api.Test;

import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
import com.puppycrawl.tools.checkstyle.checks.coding.AvoidNoArgumentSuperConstructorCallCheck;

public class XpathRegressionAvoidNoArgumentSuperConstructorCallTest
        extends AbstractXpathTestSupport {

    private static final Class<AvoidNoArgumentSuperConstructorCallCheck> CLASS =
        AvoidNoArgumentSuperConstructorCallCheck.class;

    @Override
    protected String getCheckName() {
        return CLASS.getSimpleName();
    }

    @Test
    public void testOne() throws Exception {
        final File fileToProcess = new File(getPath(
            "SuppressionXpathRegressionAvoidNoArgumentSuperConstructorCall.java"));

        final DefaultConfiguration moduleConfig =
                createModuleConfig(CLASS);

        final String[] expectedViolation = {
            "5:9: " + getCheckMessage(CLASS,
                AvoidNoArgumentSuperConstructorCallCheck.MSG_CTOR),
        };

        final List<String> expectedXpathQueries = Collections.singletonList(
                "/CLASS_DEF[./IDENT"
                    + "[@text='SuppressionXpathRegressionAvoidNoArgumentSuperConstructorCall']]"
                    + "/OBJBLOCK/CTOR_DEF[./IDENT["
                    + "@text='SuppressionXpathRegressionAvoidNoArgumentSuperConstructorCall']]"
                    + "/SLIST/SUPER_CTOR_CALL"
        );

        runVerifications(moduleConfig, fileToProcess, expectedViolation, expectedXpathQueries);
    }
}

==> checkstyle_8.36.1.orig.tar.xz: checkstyle-checkstyle-8.36.1/src/it/java/org/checkstyle/suppressionxpathfilter/XpathRegressionAvoidNoArgumentSuperConstructorCallTest.java <==
////////////////////////////////////////////////////////////////////////////////
// checkstyle: Checks Java source code for adherence to a set of rules.
// Copyright (C) 2001-2020 the original author or authors.
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

package org.checkstyle.suppressionxpathfilter;

import java.io.File;
import java.util.Collections;
import java.util.List;

import org.junit.jupiter.api.Test;

import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
import com.puppycrawl.tools.checkstyle.checks.coding.AvoidNoArgumentSuperConstructorCallCheck;

public class XpathRegressionAvoidNoArgumentSuperConstructorCallTest
        extends AbstractXpathTestSupport {

    private static final Class<AvoidNoArgumentSuperConstructorCallCheck> CLASS =
        AvoidNoArgumentSuperConstructorCallCheck.class;

    @Override
    protected String getCheckName() {
        return CLASS.getSimpleName();
    }

    @Test
    public void testDefault() throws Exception {
        final File fileToProcess = new File(getPath(
            "SuppressionXpathRegressionAvoidNoArgumentSuperConstructorCall.java"));

        final DefaultConfiguration moduleConfig =
                createModuleConfig(CLASS);

        final String[] expectedViolation = {
            "5:9: " + getCheckMessage(CLASS,
                AvoidNoArgumentSuperConstructorCallCheck.MSG_CTOR),
        };

        final List<String> expectedXpathQueries = Collections.singletonList(
                "/CLASS_DEF[./IDENT"
                    + "[@text='SuppressionXpathRegressionAvoidNoArgumentSuperConstructorCall']]"
                    + "/OBJBLOCK/CTOR_DEF[./IDENT["
                    + "@text='SuppressionXpathRegressionAvoidNoArgumentSuperConstructorCall']]"
                    + "/SLIST/SUPER_CTOR_CALL"
        );

        runVerifications(moduleConfig, fileToProcess, expectedViolation, expectedXpathQueries);
    }

    @Test
    public void testInnerClass() throws Exception {
        final File fileToProcess = new File(getPath(
            "SuppressionXpathRegressionAvoidNoArgumentSuperConstructorCallInnerClass.java"
        ));

        final DefaultConfiguration moduleConfig =
                createModuleConfig(CLASS);

        final String[] expectedViolation = {
            "7:17: " + getCheckMessage(CLASS,
                AvoidNoArgumentSuperConstructorCallCheck.MSG_CTOR),
        };

        final List<String> expectedXpathQueries = Collections.singletonList(
            "/CLASS_DEF[./IDENT[@text="
                + "'SuppressionXpathRegressionAvoidNoArgumentSuperConstructorCallInnerClass']]"
                + "/OBJBLOCK/METHOD_DEF[./IDENT[@text='test']]"
                + "/SLIST/CLASS_DEF[./IDENT[@text='Inner']]"
                + "/OBJBLOCK/CTOR_DEF[./IDENT[@text='Inner']]"
                + "/SLIST/SUPER_CTOR_CALL"
        );

        runVerifications(moduleConfig, fileToProcess, expectedViolation, expectedXpathQueries);
    }
}
